@@ -6,7 +6,7 @@
 #include <regex.h>
 
 
-enum { LOGOP_INVALID = 0, LOGOP_AND = 1, LOGOP_OR, MATCHOP_EQ, MATCHOP_NE, MATCHOP_RXEQ, MATCHOP_RXNE, MATCHOP_LT, MATCHOP_GT, MATCHOP_LE, MATCHOP_GE, MATCHOP_CONTAINS, MATCHOP_CONTAINSNOT };
+enum { LOGOP_INVALID = 0, LOGOP_AND = 1, LOGOP_OR, MATCHOP_EQ, MATCHOP_NE, MATCHOP_RXEQ, MATCHOP_RXNE, MATCHOP_LT, MATCHOP_GT, MATCHOP_LE, MATCHOP_GE, MATCHOP_CONTAINS, MATCHOP_CONTAINSNOT, MATCHOP_BETWEEN };
 
 struct expression {
 	expression(const std::string& n, const std::string& lit, int o);
@@ -39,6 +39,8 @@ class FilterParser {
 		inline expression * get_root() { return root; }
 		FilterParser& operator=(FilterParser& p);
 
+		const std::wstring& get_error() { return errmsg; }
+
 	private:
 		void print_tree_r(expression * e, unsigned int depth);
 		void cleanup_r(expression * e);
@@ -47,6 +49,7 @@ class FilterParser {
 		expression * curpos;
 		bool next_must_descend_right;
 		std::string strexpr;
+		std::wstring errmsg;
 };
 
 
