@@ -5,6 +5,7 @@
 #include <matcher.h>
 #include <history.h>
 #include <regexmanager.h>
+#include <view.h>
 
 namespace newsbeuter {
 
@@ -22,10 +23,17 @@ class feedlist_formaction : public formaction {
 		virtual keymap_hint_entry * get_keymap_hint();
 		std::tr1::shared_ptr<rss_feed> get_feed();
 
+		virtual void set_redraw(bool b) { 
+			formaction::set_redraw(b); 
+			apply_filter = !(v->get_cfg()->get_configvalue_as_bool("show-read-feeds"));
+		}
+
 		virtual std::string id() const { return "feedlist"; }
+		virtual std::string title();
 
 		bool jump_to_next_unread_feed(unsigned int& feedpos);
 		bool jump_to_previous_unread_feed(unsigned int& feedpos);
+		bool jump_to_random_unread_feed(unsigned int& feedpos);
 
 		virtual void handle_cmdline(const std::string& cmd);
 
@@ -76,6 +84,11 @@ class feedlist_formaction : public formaction {
 		regexmanager * rxman;
 
 		unsigned int old_width;
+
+		unsigned int unread_feeds;
+		unsigned int total_feeds;
+
+		std::string old_sort_order;
 };
 
 }
