@@ -50,7 +50,8 @@ namespace newsbeuter {
 						OP_SHOWURLS,
 						OP_CLEARTAG, 
 						OP_SETTAG, 
-						OP_SEARCH, 
+						OP_SEARCH,
+						OP_GOTO_URL,
 						OP_ENQUEUE,
 						OP_REDRAW,
 						OP_CMDLINE,
@@ -94,6 +95,9 @@ namespace newsbeuter {
 						OP_SK_PGUP,
 						OP_SK_PGDOWN,
 						/* TODO: add more user-defined keys here */
+						OP_SK_HOME,
+						OP_SK_END,
+						
 						OP_SK_MAX,
 
 						OP_INT_MIN = 2000,
@@ -104,6 +108,8 @@ namespace newsbeuter {
 						OP_INT_EDITFLAGS_END,
 						OP_INT_START_SEARCH,
 
+						OP_INT_GOTO_URL,
+
 						OP_INT_END_QUESTION,
 						OP_INT_CANCEL_QNA,
 						OP_INT_QNA_NEXTHIST,
