@@ -5,8 +5,8 @@
 #include <string>
 
 #include <logger.h>
-#include <rss.h>
 #include <curl/curl.h>
+#include <configcontainer.h>
 
 namespace newsbeuter {
 
@@ -26,7 +26,7 @@ class utils {
 
 		static std::string get_command_output(const std::string& cmd);
 		static void extract_filter(const std::string& line, std::string& filter, std::string& url);
-		static std::string retrieve_url(const std::string& url, configcontainer * cfgcont = NULL);
+		static std::string retrieve_url(const std::string& url, configcontainer * cfgcont = NULL, const char * authinfo = NULL);
 		static void run_command(const std::string& cmd, const std::string& param); // used for notifications only
 		static std::string run_program(char * argv[], const std::string& input);
 
@@ -75,6 +75,12 @@ class utils {
 
 		static void set_common_curl_options(CURL * handle, configcontainer * cfg);
 
+		static curl_proxytype get_proxy_type(const std::string& type);
+
+		static bool is_special_url(const std::string& url);
+
+		static bool is_http_url(const std::string& url);
+
 	private:
 		static void append_escapes(std::string& str, char c);
 
