@@ -31,8 +31,8 @@ namespace newsbeuter {
 
 			std::string id();
 
-			void set_feedlist(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds);
-			void update_visible_feeds(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds);
+			void set_feedlist(std::vector<std::tr1::shared_ptr<rss_feed> > feeds);
+			void update_visible_feeds(std::vector<std::tr1::shared_ptr<rss_feed> > feeds);
 			void set_keymap(keymap * k);
 			void set_config_container(configcontainer * cfgcontainer);
 			void show_error(const std::string& msg);
@@ -97,6 +97,8 @@ namespace newsbeuter {
 			void inside_qna(bool f);
 			void inside_cmdline(bool f);
 
+			void dump_current_form();
+
 		protected:
 			void set_bindings(std::tr1::shared_ptr<formaction> fa);
 			void apply_colors(std::tr1::shared_ptr<formaction> fa);
