@@ -24,8 +24,8 @@ static size_t my_write_data(void *buffer, size_t size, size_t nmemb, void *userp
 
 namespace rsspp {
 
-parser::parser(unsigned int timeout, const char * user_agent, const char * proxy, const char * proxy_auth) 
-	: to(timeout), ua(user_agent), prx(proxy), prxauth(proxy_auth), doc(0), lm(0) {
+parser::parser(unsigned int timeout, const char * user_agent, const char * proxy, const char * proxy_auth, curl_proxytype proxy_type) 
+	: to(timeout), ua(user_agent), prx(proxy), prxauth(proxy_auth), prxtype(proxy_type), doc(0), lm(0) {
 }
 
 parser::~parser() {
@@ -89,6 +89,8 @@ feed parser::parse_url(const std::string& url, time_t lastmodified, const std::s
 	if (prxauth)
 		curl_easy_setopt(easyhandle, CURLOPT_PROXYUSERPWD, prxauth);
 
+	curl_easy_setopt(easyhandle, CURLOPT_PROXYTYPE, prxtype);
+
 	header_values hdrs = { 0, "" };
 
 	curl_slist * custom_headers = NULL;
@@ -135,7 +137,7 @@ feed parser::parse_url(const std::string& url, time_t lastmodified, const std::s
 
 	if (buf.length() > 0) {
 		LOG(LOG_DEBUG, "parser::parse_url: handing over data to parse_buffer()");
-		return parse_buffer(buf.c_str(), buf.length());
+		return parse_buffer(buf.c_str(), buf.length(), url.c_str());
 	}
 
 	return feed();
@@ -194,7 +196,9 @@ feed parser::parse_xmlnode(xmlNode* node) {
 					f.rss_version = RSS_0_91;
 				else if (strcmp(version, "0.92")==0)
 					f.rss_version = RSS_0_92;
-				else if (strcmp(version, "2.0")==0)
+				else if (strcmp(version, "0.94")==0)
+					f.rss_version = RSS_0_94;
+				else if (strcmp(version, "2.0")==0 || strcmp(version, "2")==0)
 					f.rss_version = RSS_2_0;
 				else {
 					xmlFree((void *)version);
