@@ -42,6 +42,7 @@ configcontainer::configcontainer()
 	config_data["notify-screen"]   = configdata("no", configdata::BOOL);
 	config_data["notify-always"]   = configdata("no", configdata::BOOL);
 	config_data["notify-xterm"]    = configdata("no", configdata::BOOL);
+	config_data["notify-beep"]     = configdata("no", configdata::BOOL);
 	config_data["notify-program"]  = configdata("", configdata::PATH);
 	config_data["notify-format"]   = configdata(_("newsbeuter: finished reload, %f unread feeds (%n unread articles total)"), configdata::STR);
 	config_data["datetime-format"] = configdata("%b %d", configdata::STR);
@@ -52,7 +53,7 @@ configcontainer::configcontainer()
 	config_data["opml-url"]        = configdata("", configdata::STR, true);
 	config_data["html-renderer"]   = configdata("internal", configdata::PATH);
 	config_data["feedlist-format"] = configdata("%4i %n %11u %t", configdata::STR);
-	config_data["articlelist-format"] = configdata("%4i %f %D   %?T?|%-17T|  &?%t", configdata::STR);
+	config_data["articlelist-format"] = configdata("%4i %f %D %6L  %?T?|%-17T|  &?%t", configdata::STR);
 	config_data["text-width"]      = configdata("0", configdata::INT);
 	config_data["always-display-description"] = configdata("false", configdata::BOOL);
 	config_data["reload-only-visible-feeds"] = configdata("false", configdata::BOOL);
@@ -72,6 +73,8 @@ configcontainer::configcontainer()
 	config_data["pager"] = configdata("internal", configdata::PATH);
 	config_data["history-limit"] = configdata("100", configdata::INT);
 	config_data["prepopulate-query-feeds"] = configdata("false", configdata::BOOL);
+	config_data["goto-first-unread"] = configdata("true", configdata::BOOL);
+	config_data["proxy-type"] = configdata("http", configdata::STR);
 
 	/* title formats: */
 	config_data["feedlist-title-format"] = configdata(_("%N %V - Your feeds (%u unread, %t total)%?T? - tag `%T'&?"), configdata::STR);
