@@ -220,6 +220,7 @@ void controller::run(int argc, char * argv[]) {
 	if (do_import) {
 		LOG(LOG_INFO,"Importing OPML file from %s",importfile.c_str());
 		urlcfg = new file_urlreader(url_file);
+		urlcfg->reload();
 		import_opml(importfile.c_str());
 		return;
 	}
@@ -671,6 +672,10 @@ void controller::notify(const std::string& msg) {
 		std::cout << "\033]2;" << msg << "\033\\";
 		std::cout.flush();
 	}
+	if (cfg.get_configvalue_as_bool("notify-beep")) {
+		LOG(LOG_DEBUG, "controller:notify: notifying beep");
+		::beep();
+	}
 	if (cfg.get_configvalue("notify-program").length() > 0) {
 		std::string prog = cfg.get_configvalue("notify-program");
 		LOG(LOG_DEBUG, "controller:notify: notifying external program `%s'", prog.c_str());
@@ -808,7 +813,7 @@ void controller::export_opml() {
 	xmlNodePtr body = xmlNewTextChild(opml_node, NULL, (const xmlChar *)"body", NULL);
 
 	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin(); it != feeds.end(); ++it) {
-		if ((*it)->rssurl().substr(0,6) != "query:" && (*it)->rssurl().substr(0,7) != "filter:") {
+		if (!utils::is_special_url((*it)->rssurl())) {
 			std::string rssurl = (*it)->rssurl();
 			std::string link = (*it)->link();
 			std::string title = (*it)->title();
@@ -992,10 +997,6 @@ void controller::edit_urls_file() {
 	reload_urls_file();
 }
 
-void controller::set_feedptrs(std::tr1::shared_ptr<rss_feed> feed) {
-	feed->set_feedptrs(feed);
-}
-
 std::string controller::bookmark(const std::string& url, const std::string& title, const std::string& description) {
 	std::string bookmark_cmd = cfg.get_configvalue("bookmark-cmd");
 	bool is_interactive = cfg.get_configvalue_as_bool("bookmark-interactive");
@@ -1131,7 +1132,7 @@ void controller::enqueue_items(std::tr1::shared_ptr<rss_feed> feed) {
 	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=feed->items().begin();it!=feed->items().end();++it) {
 		if (!(*it)->enqueued() && (*it)->enclosure_url().length() > 0) {
 			LOG(LOG_DEBUG, "controller::reload: enclosure_url = `%s' enclosure_type = `%s'", (*it)->enclosure_url().c_str(), (*it)->enclosure_type().c_str());
-			if (is_valid_podcast_type((*it)->enclosure_type())) {
+			if (is_valid_podcast_type((*it)->enclosure_type()) && utils::is_http_url((*it)->enclosure_url())) {
 				LOG(LOG_INFO, "controller::reload: enqueuing `%s'", (*it)->enclosure_url().c_str());
 				enqueue_url((*it)->enclosure_url(), feed);
 				(*it)->set_enqueued(true);
