@@ -39,7 +39,6 @@ void feedlist_formaction::init() {
 	f->run(-3); // compute all widget dimensions
 
 	if(v->get_ctrl()->get_refresh_on_start()) {
-		f->run(-1); // FRUN
 		v->get_ctrl()->start_reload_all_thread();
 	}
 	v->get_ctrl()->update_feedlist();
@@ -49,7 +48,6 @@ void feedlist_formaction::init() {
 	 * The feedlist_formaction is responsible for starting up the reloadthread, which is responsible
 	 * for regularly spawning downloadthreads.
 	 */
-	f->run(-1); // FRUN
 	reloadthread  * rt = new reloadthread(v->get_ctrl(), v->get_cfg());
 	rt->start();
 
@@ -178,6 +176,9 @@ void feedlist_formaction::process_operation(operation op, bool automatic, std::v
 						v->get_ctrl()->mark_all_read(pos);
 						do_redraw = true;
 						v->set_status("");
+						if (feeds_shown > (pos + 1) && !apply_filter) {
+							f->set("feedpos", utils::to_s(pos + 1));
+						}
 					} catch (const dbexception& e) {
 						v->show_error(utils::strprintf(_("Error: couldn't mark feed read: %s"), e.what()));
 					}
