@@ -22,7 +22,7 @@ itemlist_formaction::itemlist_formaction(view * vv, std::string formstr)
 		search_dummy_feed(new rss_feed(v->get_ctrl()->get_cache())),
 		set_filterpos(false), filterpos(0), rxman(0), old_width(0), old_itempos(-1) {
 	assert(true==m.parse(FILTER_UNREAD_ITEMS));
-	old_sort_order = v->get_cfg()->get_configvalue("article-sort-order");
+	old_sort_order = "";
 }
 
 itemlist_formaction::~itemlist_formaction() { }
@@ -586,11 +586,12 @@ void itemlist_formaction::prepare() {
 		fmt.register_fmt('i', utils::strprintf("%u",it->second + 1));
 		fmt.register_fmt('f', gen_flags(it->first));
 		fmt.register_fmt('D', gen_datestr(it->first->pubDate_timestamp(), datetimeformat.c_str()));
-		if (feed->rssurl() != it->first->feedurl()) {
+		if (feed->rssurl() != it->first->feedurl() && it->first->get_feedptr() != NULL) {
 			fmt.register_fmt('T', it->first->get_feedptr()->title());
 		}
 		fmt.register_fmt('t', it->first->title());
 		fmt.register_fmt('a', it->first->author());
+		fmt.register_fmt('L', it->first->length());
 
 		listfmt.add_line(fmt.do_format(itemlist_format, width), it->second);
 	}
@@ -609,6 +610,10 @@ void itemlist_formaction::init() {
 	set_keymap_hints();
 	apply_filter = !(v->get_cfg()->get_configvalue_as_bool("show-read-articles"));
 	update_visible_items = true;
+	do_update_visible_items();
+	if (v->get_cfg()->get_configvalue_as_bool("goto-first-unread")) {
+		jump_to_next_unread_item(true);
+	}
 	f->run(-3); // FRUN - compute all widget dimensions
 }
 
