@@ -170,9 +170,11 @@ void itemview_formaction::process_operation(operation op, bool automatic, std::v
 			do_redraw = true;
 			break;
 		case OP_ENQUEUE: {
-				if (item->enclosure_url().length() > 0) {
+				if (item->enclosure_url().length() > 0 && utils::is_http_url(item->enclosure_url())) {
 					v->get_ctrl()->enqueue_url(item->enclosure_url(), feed);
 					v->set_status(utils::strprintf(_("Added %s to download queue."), item->enclosure_url().c_str()));
+				} else {
+					v->set_status(utils::strprintf(_("Invalid URL: '%s'"), item->enclosure_url().c_str()));
 				}
 			}
 			break;
@@ -263,6 +265,11 @@ void itemview_formaction::process_operation(operation op, bool automatic, std::v
 				v->show_error(_("URL list empty."));
 			}
 			break;
+		case OP_DELETE:
+			LOG(LOG_INFO, "view::run_itemview: deleting current article");
+			item->set_deleted(true);
+			v->get_ctrl()->mark_deleted(guid, true);
+			/* fall-through! */
 		case OP_NEXTUNREAD:
 			LOG(LOG_INFO, "view::run_itemview: jumping to next unread article");
 			if (v->get_next_unread(itemlist.get(), this)) {
@@ -327,6 +334,20 @@ void itemview_formaction::process_operation(operation op, bool automatic, std::v
 				}
 			}
 			break;
+		case OP_GOTO_URL: {
+				std::vector<qna_pair> qna;
+				if (automatic) {
+					if (args->size() > 0) {
+						qna_responses.clear();
+						qna_responses.push_back((*args)[0]);
+						finished_qna(OP_INT_GOTO_URL);
+					}
+				} else {
+					qna.push_back(qna_pair(_("Goto URL #"), ""));
+					this->start_qna(qna, OP_INT_GOTO_URL);
+				}
+			}
+			break;
 		default:
 			break;
 	}
@@ -452,6 +473,16 @@ void itemview_formaction::finished_qna(operation op) {
 				v->pop_current_formaction();
 			}
 			break;
+                case OP_INT_GOTO_URL: {
+                                unsigned int idx = 0;
+                                sscanf(qna_responses[0].c_str(),"%u",&idx);
+				if(idx && idx-1 < links.size()) {
+					v->set_status(_("Starting browser..."));
+					v->open_in_browser(links[idx-1].first);
+					v->set_status("");
+				}
+                        }
+                        break;
 		default:
 			break;
 	}
