@@ -46,11 +46,13 @@ rss_feed::~rss_feed() {
 
 void rss_item::set_title(const std::string& t) { 
 	title_ = t; 
+	utils::trim(title_);
 }
 
 
 void rss_item::set_link(const std::string& l) { 
 	link_ = l; 
+	utils::trim(link_);
 }
 
 void rss_item::set_author(const std::string& a) { 
@@ -61,6 +63,18 @@ void rss_item::set_description(const std::string& d) {
 	description_ = d; 
 }
 
+std::string rss_item::length() const {
+    std::string::size_type l = description_.length(); // get length from raw!
+	if (!l)
+		return "";
+	if (l < 1000)
+	return utils::strprintf("%u ", l);
+	if (l < 1024*1000)
+		return utils::strprintf("%.1fK", l/1024.0);
+
+	return utils::strprintf("%.1fM", l/1024.0/1024.0);
+}
+
 void rss_item::set_pubDate(time_t t) { 
 	pubDate_ = t; 
 }
@@ -103,7 +117,7 @@ std::string rss_item::pubDate() const {
 }
 
 unsigned int rss_feed::unread_item_count() {
-	// scope_mutex lock(&item_mutex);
+	scope_mutex lock(&item_mutex);
 	unsigned int count = 0;
 	for (std::vector<std::tr1::shared_ptr<rss_item> >::const_iterator it=items_.begin();it!=items_.end();++it) {
 		if ((*it)->unread())
