@@ -261,7 +261,7 @@ std::string utils::convert_text(const std::string& text, const std::string& toco
  * of all the Unix-like systems around there, only Linux/glibc seems to 
  * come with a SuSv3-conforming iconv implementation.
  */
-#ifndef __linux
+#if !(__linux) && !defined(__GLIBC__)
 	const char * inbufp;
 #else
 	char * inbufp;
@@ -334,7 +334,7 @@ static size_t my_write_data(void *buffer, size_t size, size_t nmemb, void *userp
 	return size * nmemb;
 }
 
-std::string utils::retrieve_url(const std::string& url, configcontainer * cfgcont) {
+std::string utils::retrieve_url(const std::string& url, configcontainer * cfgcont, const char * authinfo) {
 	std::string buf;
 
 	CURL * easyhandle = curl_easy_init();
@@ -343,6 +343,11 @@ std::string utils::retrieve_url(const std::string& url, configcontainer * cfgcon
 	curl_easy_setopt(easyhandle, CURLOPT_WRITEFUNCTION, my_write_data);
 	curl_easy_setopt(easyhandle, CURLOPT_WRITEDATA, &buf);
 
+	if (authinfo) {
+		curl_easy_setopt(easyhandle, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
+		curl_easy_setopt(easyhandle, CURLOPT_USERPWD, authinfo);
+	}
+
 	curl_easy_perform(easyhandle);
 	curl_easy_cleanup(easyhandle);
 
@@ -491,18 +496,23 @@ std::string utils::absolute_url(const std::string& url, const std::string& link)
 
 std::string utils::strprintf(const char * format, ...) {
 	if (!format)
-		return std::string("");
+		return std::string();
+
+	char buffer[1024];
 
 	va_list ap;
 	va_start(ap, format);
 
-	unsigned int len = vsnprintf(NULL, 0, format, ap);
+	unsigned int len = vsnprintf(buffer, sizeof(buffer), format, ap)+1;
 
 	va_end(ap);
+	if (len <= sizeof(buffer))
+		return buffer;
+
 	va_start(ap, format);
 
-	char * buf = new char[len + 1];
-	vsnprintf(buf, len + 1, format, ap);
+	char * buf = new char[len];
+	vsnprintf(buf, len, format, ap);
 	va_end(ap);
 
 	std::string ret(buf);
@@ -562,6 +572,8 @@ bool utils::is_valid_color(const std::string& color) {
 		if (color == colors[i])
 			return true;
 	}
+	if (strncmp(color.c_str(), "color", 5)==0)
+		return true;
 	return false;
 }
 
@@ -590,7 +602,10 @@ std::vector<std::pair<unsigned int, unsigned int> > utils::partition_indexes(uns
 
 size_t utils::strwidth(const std::string& str) {
 	std::wstring wstr = str2wstr(str);
-	return wcswidth(wstr.c_str(), wstr.length());
+	int width = wcswidth(wstr.c_str(), wstr.length());
+	if (width < 1) // a non-printable character found?
+		return wstr.length(); // return a sane width (which might be larger than necessary)
+	return width; // exact width
 }
 
 std::string utils::join(const std::vector<std::string>& strings, const std::string& separator) {
@@ -607,9 +622,17 @@ std::string utils::join(const std::vector<std::string>& strings, const std::stri
 	return result;
 }
 
+bool utils::is_special_url(const std::string& url) {
+	return url.substr(0,6) == "query:" || url.substr(0,7) == "filter:" || url.substr(0,5) == "exec:";
+}
+
+bool utils::is_http_url(const std::string& url) {
+	return url.substr(0,7) == "http://" || url.substr(0,8) == "https://";
+}
+
 std::string utils::censor_url(const std::string& url) {
 	std::string rv;
-	if (url.length() > 0) {
+	if (url.length() > 0 && !utils::is_special_url(url)) {
 		const char * myuri = url.c_str();
 		xmlURIPtr uri = xmlParseURI(myuri);
 		if (uri) {
@@ -624,6 +647,8 @@ std::string utils::censor_url(const std::string& url) {
 			xmlFreeURI(uri);
 		} else
 			return url;
+	} else {
+		rv = url;
 	}
 	return rv;
 }
@@ -640,7 +665,7 @@ std::string utils::quote_for_stfl(std::string str) {
 }
 
 void utils::trim(std::string& str) {
-	while (str.length() > 0 && (str[0] == ' ' || str[0] == '\n' || str[0] == '\r')) {
+	while (str.length() > 0 && ::isspace(str[0])) {
 		str.erase(0,1);
 	}
 	trim_end(str);
@@ -686,13 +711,17 @@ std::string utils::quote_if_necessary(const std::string& str) {
 void utils::set_common_curl_options(CURL * handle, configcontainer * cfg) {
 	std::string proxy;
 	std::string proxyauth;
+	std::string proxytype;
 	std::string useragent; 
 	unsigned int dl_timeout = 0;
 
 
 	if (cfg) {
-		proxy = cfg->get_configvalue("proxy");
-		proxyauth = cfg->get_configvalue("proxy-auth");
+		if (cfg->get_configvalue_as_bool("use-proxy")) {
+			proxy = cfg->get_configvalue("proxy");
+			proxyauth = cfg->get_configvalue("proxy-auth");
+			proxytype = cfg->get_configvalue("proxy-type");
+		}
 		useragent = utils::get_useragent(cfg);
 		dl_timeout = cfg->get_configvalue_as_int("download-timeout");
 	}
@@ -706,6 +735,11 @@ void utils::set_common_curl_options(CURL * handle, configcontainer * cfg) {
 		curl_easy_setopt(handle, CURLOPT_PROXY, proxy.c_str());
 	if (proxyauth != "")
 		curl_easy_setopt(handle, CURLOPT_PROXYUSERPWD, proxyauth.c_str());
+	if (proxytype != "") {
+		LOG(LOG_DEBUG, "utils::set_common_curl_options: proxytype = %s", proxytype.c_str());
+		curl_easy_setopt(handle, CURLOPT_PROXYTYPE, get_proxy_type(proxytype));
+	}
+
 	curl_easy_setopt(handle, CURLOPT_USERAGENT, useragent.c_str());
 
 	curl_easy_setopt(handle, CURLOPT_FOLLOWLOCATION, 1);
@@ -713,4 +747,18 @@ void utils::set_common_curl_options(CURL * handle, configcontainer * cfg) {
 	curl_easy_setopt(handle, CURLOPT_FAILONERROR, 1);
 }
 
+curl_proxytype utils::get_proxy_type(const std::string& type) {
+	if (type == "http")
+		return CURLPROXY_HTTP;
+	if (type == "socks4")
+		return CURLPROXY_SOCKS4;
+	if (type == "socks5")
+		return CURLPROXY_SOCKS5;
+	if (type == "socks4a")
+		return CURLPROXY_SOCKS4A;
+
+	LOG(LOG_USERERROR, "you configured an invalid proxy type: %s", type.c_str());
+	return CURLPROXY_HTTP;
+}
+
 }
