@@ -28,6 +28,7 @@
 #include <iostream>
 #include <iomanip>
 #include <fstream>
+#include <cerrno>
 
 #include <assert.h>
 #include <libgen.h>
@@ -101,6 +102,11 @@ void view::set_bindings(std::tr1::shared_ptr<formaction> fa) {
 
 	fa->get_form()->set("bind_page_up", pgupkey);
 	fa->get_form()->set("bind_page_down", pgdownkey);
+
+	std::string homekey("** "); homekey.append(keys->getkey(OP_SK_HOME, fa->id()));
+	std::string endkey("** "); endkey.append(keys->getkey(OP_SK_END, fa->id()));
+	fa->get_form()->set("bind_home", homekey);
+	fa->get_form()->set("bind_end", endkey);
 }
 
 std::tr1::shared_ptr<formaction> view::get_current_formaction() {
@@ -146,6 +152,8 @@ void view::run() {
 
 	get_current_formaction()->init();
 
+	stfl::reset();
+
 	/*
 	 * This is the main "event" loop of newsbeuter.
 	 */
@@ -347,36 +355,31 @@ void view::open_in_browser(const std::string& url) {
 	pop_current_formaction();
 }
 
-void view::update_visible_feeds(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds) {
-	scope_mutex lock(mtx);
+void view::update_visible_feeds(std::vector<std::tr1::shared_ptr<rss_feed> > feeds) {
 	try {
 		if (formaction_stack_size() > 0) {
+			scope_mutex lock(mtx);
 			std::tr1::shared_ptr<feedlist_formaction> feedlist = std::tr1::dynamic_pointer_cast<feedlist_formaction, formaction>(formaction_stack[0]);
 			feedlist->update_visible_feeds(feeds);
 		}
-	} catch (matcherexception e) {
-		set_status_unlocked(utils::strprintf(_("Error: applying the filter failed: %s"), e.what()));
+	} catch (const matcherexception& e) {
+		set_status(utils::strprintf(_("Error: applying the filter failed: %s"), e.what()));
 		LOG(LOG_DEBUG, "view::update_visible_feeds: inside catch: %s", e.what());
 	}
 }
 
-void view::set_feedlist(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds) {
+void view::set_feedlist(std::vector<std::tr1::shared_ptr<rss_feed> > feeds) {
 	scope_mutex lock(mtx);
 
 	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
 		if ((*it)->rssurl().substr(0,6) != "query:") {
-			ctrl->set_feedptrs(*it);
+			(*it)->set_feedptrs(*it);
 		}
 	}
 
-	try {
-		if (formaction_stack_size() > 0) {
-			std::tr1::shared_ptr<feedlist_formaction> feedlist = std::tr1::dynamic_pointer_cast<feedlist_formaction, formaction>(formaction_stack[0]);
-			feedlist->set_feedlist(feeds);
-		}
-	} catch (matcherexception e) {
-		set_status_unlocked(utils::strprintf(_("Error: applying the filter failed: %s"), e.what()));
-		LOG(LOG_DEBUG, "view::set_feedlist: inside catch: %s", e.what());
+	if (formaction_stack_size() > 0) {
+		std::tr1::shared_ptr<feedlist_formaction> feedlist = std::tr1::dynamic_pointer_cast<feedlist_formaction, formaction>(formaction_stack[0]);
+		feedlist->set_feedlist(feeds);
 	}
 }
 
@@ -481,6 +484,7 @@ void view::view_dialogs() {
 void view::push_help() {
 	std::tr1::shared_ptr<help_formaction> helpview(new help_formaction(this, help_str));
 	set_bindings(helpview);
+	apply_colors(helpview);
 	helpview->set_context(get_current_formaction()->id());
 	helpview->set_parent_formaction(get_current_formaction());
 	helpview->init();
@@ -764,6 +768,7 @@ void view::apply_colors(std::tr1::shared_ptr<formaction> fa) {
 	std::map<std::string,std::string>::const_iterator fgcit = fg_colors.begin();
 	std::map<std::string,std::string>::const_iterator bgcit = bg_colors.begin();
 	std::map<std::string,std::vector<std::string> >::const_iterator attit = attributes.begin();
+	LOG(LOG_DEBUG, "view::apply_colors: fa = %s", fa->id().c_str());
 
 	for (;fgcit != fg_colors.end(); ++fgcit, ++bgcit, ++attit) {
 		std::string colorattr;
@@ -925,4 +930,20 @@ void view::handle_cmdline_completion(std::tr1::shared_ptr<formaction> fa) {
 	last_fragment = suggestion;
 }
 
+void view::dump_current_form() {
+	std::string formtext = formaction_stack[current_formaction]->get_form()->dump("", "", 0);
+	char fnbuf[128];
+	time_t t = ::time(NULL);
+	struct tm * stm = localtime(&t);
+	strftime(fnbuf, sizeof(fnbuf), "dumpform-%Y%m%d-%H%M%S.stfl", stm);
+	std::fstream f(fnbuf, std::ios_base::out);
+	if (!f.is_open()) {
+		show_error(utils::strprintf("Error: couldn't open file %s: %s", fnbuf, strerror(errno)));
+		return;
+	}
+	f << formtext;
+	f.close();
+	set_status(utils::strprintf("Dumped current form to file %s", fnbuf));
+}
+
 }
