@@ -31,7 +31,6 @@ using namespace newsbeuter;
 
 BOOST_AUTO_TEST_CASE(InitTests) {
 	setlocale(LC_CTYPE, "");
-	setlocale(LC_MESSAGES, "");
 	GetLogger().set_logfile("testlog.txt");
 	GetLogger().set_loglevel(LOG_DEBUG);
 }
@@ -40,7 +39,7 @@ BOOST_AUTO_TEST_CASE(TestNewsbeuterReload) {
 	configcontainer * cfg = new configcontainer();
 	cache * rsscache = new cache("test-cache.db", cfg);
 
-	rss_parser parser("http://bereshit.synflood.at/~ak/rss.xml", rsscache, cfg, NULL);
+	rss_parser parser("http://testbed.newsbeuter.org/unit-test/rss.xml", rsscache, cfg, NULL);
 	std::tr1::shared_ptr<rss_feed> feed = parser.parse();
 	BOOST_CHECK_EQUAL(feed->items().size(), 8u);
 
@@ -58,7 +57,7 @@ BOOST_AUTO_TEST_CASE(TestNewsbeuterReload) {
 	rsscache->externalize_rssfeed(feed, false);
 
 	std::tr1::shared_ptr<rss_feed> feed2(new rss_feed(rsscache));
-	feed2->set_rssurl("http://bereshit.synflood.at/~ak/rss.xml");
+	feed2->set_rssurl("http://testbed.newsbeuter.org/unit-test/rss.xml");
 	rsscache->internalize_rssfeed(feed2);
 
 	BOOST_CHECK_EQUAL(feed2->items().size(), 8u);
@@ -67,7 +66,7 @@ BOOST_AUTO_TEST_CASE(TestNewsbeuterReload) {
 
 	std::vector<std::string> feedurls = rsscache->get_feed_urls();
 	BOOST_CHECK_EQUAL(feedurls.size(), 1u);
-	BOOST_CHECK_EQUAL(feedurls[0], "http://bereshit.synflood.at/~ak/rss.xml");
+	BOOST_CHECK_EQUAL(feedurls[0], "http://testbed.newsbeuter.org/unit-test/rss.xml");
 
 	std::vector<std::tr1::shared_ptr<rss_feed> > feedv;
 	feedv.push_back(feed);
@@ -181,7 +180,7 @@ BOOST_AUTO_TEST_CASE(TestConfigParserContainerAndKeymap) {
 }
 
 BOOST_AUTO_TEST_CASE(TestTagSoupPullParser) {
-	std::istringstream is("<test><foo quux='asdf' bar=\"qqq\">text</foo>more text<more>&quot;&#33;&#x40;</more></test>");
+	std::istringstream is("<test><foo quux='asdf' bar=\"qqq\">text</foo>more text<more>&quot;&#33;&#x40;</more><xxx foo=bar baz=\"qu ux\" hi='ho ho ho'></xxx></test>");
 	tagsouppullparser xpp;
 	tagsouppullparser::event e;
 	xpp.setInput(is);
@@ -215,6 +214,15 @@ BOOST_AUTO_TEST_CASE(TestTagSoupPullParser) {
 	BOOST_CHECK_EQUAL(e, tagsouppullparser::END_TAG);
 	BOOST_CHECK_EQUAL(xpp.getText(), "more");
 	e = xpp.next();
+	BOOST_CHECK_EQUAL(e, tagsouppullparser::START_TAG);
+	BOOST_CHECK_EQUAL(xpp.getText(), "xxx");
+	BOOST_CHECK_EQUAL(xpp.getAttributeValue("foo"), "bar");
+	BOOST_CHECK_EQUAL(xpp.getAttributeValue("baz"), "qu ux");
+	BOOST_CHECK_EQUAL(xpp.getAttributeValue("hi"), "ho ho ho");
+	e = xpp.next();
+	BOOST_CHECK_EQUAL(e, tagsouppullparser::END_TAG);
+	BOOST_CHECK_EQUAL(xpp.getText(), "xxx");
+	e = xpp.next();
 	BOOST_CHECK_EQUAL(e, tagsouppullparser::END_TAG);
 	BOOST_CHECK_EQUAL(xpp.getText(), "test");
 	e = xpp.next();
